* ------------------------------------------------------------------------------ ;

* CIS - Community Innovation Survey, wave 2006 - Data without Boundaries         ;

* This setup file converts the raw BULGARIA data from CSV to SAS                 ;
* Checked for the July 2013 release of the CIS, as provided by Eurostat          ;

* Version 2 of the file, March 2015                                              ;
* Tested with SAS 9.1.3 Service Pack 4                                           ;

* University of Bucharest, Romanian Social Data Archive                          ;
* Adrian Dusa                                                                    ;
* http://www.roda.ro                                                             ;
* Contact: dusa.adrian@unibuc.ro                                                 ;

* ------------------------------------------------------------------------------ ;





* ------------------------------------------------------------------------------ ;

* --- CONFIGURATION SECTION - START ---                                          ;


* The following command should contain the complete path and                     ;
* name of the .csv file to be read (e.g. "C:/CIS 2006/CSV/BG.csv")               ;
* Change CSV_DATA_PATH to your filename, below                                   ;

FILENAME csvpath "CSV_DATA_PATH";


* The following command should contain the complete path of the                  ;
* directory where the setup file will be saved (e.g. "C:/CIS 2006/SAS/")         ;
* Change SAS_DATA_FOLDER to your directory name, below                           ;

LIBNAME dirout "SAS_DATA_FOLDER";


* The following command should contain the name of the output SAS file only      ;
* (without quotes, and without the .sas7bdat extension)                          ;
* Change SAS_FILE_NAME to your output file name, below                           ;

%LET sasfile=SAS_FILE_NAME;


* --- CONFIGURATION SECTION -  END ---                                           ;

* ------------------------------------------------------------------------------ ;



* There should be nothing to change below this line;
* ------------------------------------------------------------------------------ ;



* --- Read the raw data file ---                                                 ;

DATA sasimport;

INFILE csvpath
       DLM=","
       FIRSTOBS=2
       DSD
       TRUNCOVER
       LRECL=512
       ;

INPUT  RTOT_MSK
       C_HO
       NACE_PRO $
       SIZE06
       SIZE04
       ID
       WEIGHT
       COUNTRY $
       RRDINXM
       RRDEXXM
       RMACXM
       ROEKXM
       TURN04M
       TURN06M
       GP
       MARLOC
       MARNAT
       MAREUR
       MAROTH
       INPDGD
       INPDSV
       INPDTW
       NEWMKT
       NEWFRM
       TURNMAR
       TURNIN
       TURNUNG
       INPSPD
       INPSLG
       INPSSU
       INPCSW
       INONAB
       RRDIN
       RDENG
       RRDEX
       RMAC
       ROEK
       RTR
       RMAR
       RPRE
       FUNLOC
       FUNGMT
       FUNEU
       FUNRTD
       SENTG
       SSUP
       SCLI
       SCOM
       SINS
       SUNI
       SGMT
       SCON
       SJOU
       SPRO
       CO
       CO11
       CO12
       CO13
       CO14
       CO21
       CO22
       CO23
       CO24
       CO31
       CO32
       CO33
       CO34
       CO41
       CO42
       CO43
       CO44
       CO51
       CO52
       CO53
       CO54
       CO61
       CO62
       CO63
       CO64
       CO71
       CO72
       CO73
       CO74
       PMOS $
       ERANGE
       EMAR
       EQUA
       EFLEX
       ECAP
       ELBR
       EMAT
       EENV
       ESTD
       HCON
       HBEG
       HDLAY
       HFENT
       HFOUT
       HCOS
       HPER
       HTEC
       HINF
       HPAR
       HDOM
       HDEM
       HPRIOR
       HMAR
       PROPAT
       PRODSG
       PROTM
       PROCP
       ORGSYS
       ORGSTR
       ORGREL
       MKTDES
       MKTMET
       EFORED
       EFORQU
       EFORCO
       EFORSA
       ;
RUN;

* ------------------------------------------------------------------------------ ;


* --- Recode string variables which have labels, to numeric variables ---        ;

DATA sasimport;

    SET sasimport;

    IF (NACE_PRO = 'C') THEN TEMPVAR = 1;
    IF (NACE_PRO = 'DA') THEN TEMPVAR = 2;
    IF (NACE_PRO = 'DB') THEN TEMPVAR = 3;
    IF (NACE_PRO = 'DC') THEN TEMPVAR = 4;
    IF (NACE_PRO = '20_21') THEN TEMPVAR = 5;
    IF (NACE_PRO = '22') THEN TEMPVAR = 6;
    IF (NACE_PRO = 'DF_DG') THEN TEMPVAR = 7;
    IF (NACE_PRO = 'DH') THEN TEMPVAR = 8;
    IF (NACE_PRO = 'DI') THEN TEMPVAR = 9;
    IF (NACE_PRO = '27') THEN TEMPVAR = 10;
    IF (NACE_PRO = '28') THEN TEMPVAR = 11;
    IF (NACE_PRO = 'DK') THEN TEMPVAR = 12;
    IF (NACE_PRO = 'DL') THEN TEMPVAR = 13;
    IF (NACE_PRO = 'DM') THEN TEMPVAR = 14;
    IF (NACE_PRO = 'DN') THEN TEMPVAR = 15;
    IF (NACE_PRO = 'E') THEN TEMPVAR = 16;
    IF (NACE_PRO = 'F') THEN TEMPVAR = 17;
    IF (NACE_PRO = '50') THEN TEMPVAR = 18;
    IF (NACE_PRO = '51') THEN TEMPVAR = 19;
    IF (NACE_PRO = '52') THEN TEMPVAR = 20;
    IF (NACE_PRO = 'H') THEN TEMPVAR = 21;
    IF (NACE_PRO = '60_61_62') THEN TEMPVAR = 22;
    IF (NACE_PRO = '63') THEN TEMPVAR = 23;
    IF (NACE_PRO = '64') THEN TEMPVAR = 24;
    IF (NACE_PRO = 'J') THEN TEMPVAR = 25;
    IF (NACE_PRO = '70') THEN TEMPVAR = 26;
    IF (NACE_PRO = '71') THEN TEMPVAR = 27;
    IF (NACE_PRO = '72') THEN TEMPVAR = 28;
    IF (NACE_PRO = '73_74') THEN TEMPVAR = 29;

RUN;

DATA sasimport;

    SET sasimport;

    DROP NACE_PRO;
    RENAME TEMPVAR = NACE_PRO;

RUN;

DATA sasimport;

    SET sasimport;

    IF (PMOS = 'A') THEN TEMPVAR = 1;
    IF (PMOS = 'B') THEN TEMPVAR = 2;
    IF (PMOS = 'C') THEN TEMPVAR = 3;
    IF (PMOS = 'D') THEN TEMPVAR = 4;
    IF (PMOS = 'E') THEN TEMPVAR = 5;
    IF (PMOS = 'F') THEN TEMPVAR = 6;
    IF (PMOS = 'G') THEN TEMPVAR = 7;

RUN;

DATA sasimport;

    SET sasimport;

    DROP PMOS;
    RENAME TEMPVAR = PMOS;

RUN;

* ------------------------------------------------------------------------------ ;


* --- Reorder the variables in their original positions ---                      ;

DATA sasimport;

    RETAIN ID WEIGHT COUNTRY CO62 C_HO NACE_PRO GP MARLOC MARNAT MAREUR MAROTH
           INPDGD INPDSV INPDTW NEWMKT NEWFRM TURNMAR TURNIN TURNUNG INPSPD
           INPSLG INPSSU INPCSW INONAB RRDIN RDENG RRDEX RMAC ROEK RTR RMAR
           RPRE RRDINXM RRDEXXM RMACXM ROEKXM RTOT_MSK FUNLOC FUNGMT FUNEU
           FUNRTD SENTG SSUP SCLI SCOM SINS SUNI SGMT SCON SJOU SPRO CO
           CO11 CO12 CO13 CO14 CO21 CO22 CO23 CO24 CO31 CO32 CO33 CO34
           CO41 CO42 CO43 CO44 CO51 CO52 CO53 CO54 CO61 CO63 CO64 CO71
           CO72 CO73 CO74 PMOS ERANGE EMAR EQUA EFLEX ECAP ELBR EMAT EENV
           ESTD HCON HBEG HDLAY HFENT HFOUT HCOS HPER HTEC HINF HPAR HDOM
           HDEM HPRIOR HMAR PROPAT PRODSG PROTM PROCP ORGSYS ORGSTR ORGREL
           MKTDES MKTMET EFORED EFORQU EFORCO EFORSA TURN04M TURN06M SIZE04
           SIZE06;

    SET sasimport;

RUN;

* ------------------------------------------------------------------------------ ;


* --- Add variable labels ---                                                    ;

DATA sasimport;

    SET sasimport;

    LABEL ID       = "Name of enterprise";
    LABEL WEIGHT   = "Weighting factors";
    LABEL COUNTRY  = "Country";
    LABEL CO62     = "Universities or other higher education institutions: EU/EFTA/EU-CC";
    LABEL C_HO     = "Country of head office. ISO 3166 alphanumeric 2 digit code";
    LABEL NACE_PRO = "Main activity";
    LABEL GP       = "Enterprise part of a group";
    LABEL MARLOC   = "Local/regional market";
    LABEL MARNAT   = "National I market";
    LABEL MAREUR   = "Other EU/EFTA/CC market";
    LABEL MAROTH   = "All other countries";
    LABEL INPDGD   = "Introduced onto the market a new or significantly improved good";
    LABEL INPDSV   = "Introduced onto the market a new or significantly improved service";
    LABEL INPDTW   = "Who mainly developed these products";
    LABEL NEWMKT   = "Did the enterprise introduce a product new to the market";
    LABEL NEWFRM   = "Did the enterprise introduce a product new to the firm";
    LABEL TURNMAR  = "% of turnover in new or improved products introduced during 2004-2006 that were new to the market";
    LABEL TURNIN   = "% of turnover in unchanged or marginally modified products during  2004-2006 that were new to the firm";
    LABEL TURNUNG  = "% of turnover in unchanged or marginally modified products during 2004-2006";
    LABEL INPSPD   = "Introduced onto the market a new or significantly improved method of production";
    LABEL INPSLG   = "Introduced onto the market a new or significantly improved logistic, delivery or distribution system";
    LABEL INPSSU   = "Introduced onto the market a new or significantly improved supporting activities";
    LABEL INPCSW   = "Who mainly developed these processes";
    LABEL INONAB   = "Enterprise with ongoing or abandoned innovation activities";
    LABEL RRDIN    = "Engagement in intramural R&D";
    LABEL RDENG    = "Type of engagement in R&D";
    LABEL RRDEX    = "Engagement in extramural R&D";
    LABEL RMAC     = "Engagement in acquisition of machinery";
    LABEL ROEK     = "Engagement in other external knowledge";
    LABEL RTR      = "Engagement in training";
    LABEL RMAR     = "Engagement in market introduction of innovation";
    LABEL RPRE     = "Engagement in other preparation";
    LABEL RRDINXM  = "Expenditure in intramural R&D";
    LABEL RRDEXXM  = "Expenditure in extramural R&D";
    LABEL RMACXM   = "Expenditure in acquisition of machinery";
    LABEL ROEKXM   = "Expenditure in other external knowledge";
    LABEL RTOT_MSK = "Total for four expenditure categories";
    LABEL FUNLOC   = "Public funding from local or regional autorities";
    LABEL FUNGMT   = "Public funding from central government";
    LABEL FUNEU    = "Public funding from the EU";
    LABEL FUNRTD   = "Public from EU's 5th or 6th RTD";
    LABEL SENTG    = "Sources from within the enterprise or enterprise group";
    LABEL SSUP     = "Sources from Suppliers of equipment, materials, etc";
    LABEL SCLI     = "Sources from Clients or customers";
    LABEL SCOM     = "Sources from Competitors and other enterprises of same industry";
    LABEL SINS     = "Sources from consultants, commercial labs or private R&D institutes";
    LABEL SUNI     = "Sources from Universities or other higher education institutes";
    LABEL SGMT     = "Sources from Government or public research institutes";
    LABEL SCON     = "Sources from professional conferences, trade fairs, meetings";
    LABEL SJOU     = "Sources from Scientific journals, trade/scientific publications";
    LABEL SPRO     = "Sources from Professional and industry associations";
    LABEL CO       = "Cooperation arrangements on innovation activities";
    LABEL CO11     = "Other enterprises within enterprise group: National";
    LABEL CO12     = "Other enterprises within enterprise group: EU/EFTA/EU-CC";
    LABEL CO13     = "Other enterprises within enterprise group: US";
    LABEL CO14     = "Other enterprises within enterprise group: Other countries";
    LABEL CO21     = "Suppliers of equipment, etc: National";
    LABEL CO22     = "Suppliers of equipment, etc: EU/EFTA/EU-CC";
    LABEL CO23     = "Suppliers of equipment, etc: US";
    LABEL CO24     = "Suppliers of equipment, etc: Other countries";
    LABEL CO31     = "Clients or customers: National";
    LABEL CO32     = "Clients or customers: EU/EFTA/EU-CC";
    LABEL CO33     = "Clients or customers : US";
    LABEL CO34     = "Clients or customers: Other countries";
    LABEL CO41     = "Competitors or other firms ... : National";
    LABEL CO42     = "Competitors or other firms ...: EU/EFTA/EU-CC";
    LABEL CO43     = "Competitors or other firms ...: US";
    LABEL CO44     = "Competitors or other firms ... : Other countries";
    LABEL CO51     = "Consultants, commercial labs, private R&D institutes: National";
    LABEL CO52     = "Consultants, commercial labs, private R&D institutes: EU/EFTA/EU-CC";
    LABEL CO53     = "Consultants, commercial labs, private R&D institutes: US";
    LABEL CO54     = "Consultants, commercial labs, private R&D institutes: Other countries";
    LABEL CO61     = "Universities or other ...: National";
    LABEL CO63     = "Universities or other ... : US";
    LABEL CO64     = "Universities or other ... : Other countries";
    LABEL CO71     = "Government or public research institutes: National";
    LABEL CO72     = "Government or public research institutes: EU/EFTA/EU-CC";
    LABEL CO73     = "Government or public research institutes: US";
    LABEL CO74     = "Government or public research institutes: Other countries";
    LABEL PMOS     = "Most important co-operation partner";
    LABEL ERANGE   = "Increased range of goods or services";
    LABEL EMAR     = "Increased market or market share";
    LABEL EQUA     = "Improved quality in goods or services";
    LABEL EFLEX    = "Improved production flexibility";
    LABEL ECAP     = "Increased production capacity";
    LABEL ELBR     = "Reduced labour costs per produced unit";
    LABEL EMAT     = "Reduced materials and energy per produced unit";
    LABEL EENV     = "Reduced environmental impact or health and safety aspects";
    LABEL ESTD     = "Met regulations or standards";
    LABEL HCON     = "Innovation activity abandoned at concept stage";
    LABEL HBEG     = "Innovation activity abandoned after the activity/project begun";
    LABEL HDLAY    = "Innovation activity seriously delayed";
    LABEL HFENT    = "Hampering factor: Lack of funds within enterprises or ent. group";
    LABEL HFOUT    = "Hampering factor : Lack of outside funds";
    LABEL HCOS     = "Hampering factor : Innovation costs too high";
    LABEL HPER     = "Hampering factor : Lack of qualified personnel";
    LABEL HTEC     = "Hampering factor : Lack of information on technology";
    LABEL HINF     = "Hampering factor : Lack of information on markets";
    LABEL HPAR     = "Hampering factor : Difficulty in finding co-operation partners";
    LABEL HDOM     = "Hampering factor : Market dominated by established enterprises";
    LABEL HDEM     = "Hampering factor: Uncertain demand for innovative goods/services";
    LABEL HPRIOR   = "No innovation activity due to prior innovations";
    LABEL HMAR     = "No innovation activity due to no demand for innovations";
    LABEL PROPAT   = "Applied for a patent";
    LABEL PRODSG   = "Registered an industrial design";
    LABEL PROTM    = "Register a trademark";
    LABEL PROCP    = "Claimed copyright";
    LABEL ORGSYS   = "Introduce improved knowledge management system";
    LABEL ORGSTR   = "Introduce change to work organisation";
    LABEL ORGREL   = "Introduce a change in relations with other firms...";
    LABEL MKTDES   = "Introduce significant design/packaging changes";
    LABEL MKTMET   = "Introduce significantly changed sales/distribution methods";
    LABEL EFORED   = "Reduced time to respond to customers needs";
    LABEL EFORQU   = "Improved quality of goods/services";
    LABEL EFORCO   = "Reduced costs per unit output";
    LABEL EFORSA   = "Improved employee satisfaction";
    LABEL TURN04M  = "Total turnover in 2004";
    LABEL TURN06M  = "Total turnover in 2006";
    LABEL SIZE04   = "Total number of employees in 2004";
    LABEL SIZE06   = "Total number of employees in 2006";

RUN;

* ------------------------------------------------------------------------------ ;


* --- Create value labels groups ---                                             ;

PROC FORMAT;

VALUE LABELS_1_GROUP
      0="No"
      1="Yes";

VALUE LABELS_2_GROUP
      0="No answer"
      1="Home country"
      2="EU,EFTA,CC"
      3="rest of the world";

VALUE LABELS_3_GROUP
      1="Mining and quarrying"
      2="Manufacture of food products, beverages and tobacco"
      3="Manufacture of textiles and textile products"
      4="Manufacture of leather and leather products"
      5="Manufacture of wood and wood products; manufacture of pulp, paper and paper products"
      6="Publishing, printing and reproduction of recorded media"
      7="Manufacture of coke, refined petroleum products and nuclear fuel, of chemicals, chemical products and man-made fibres"
      8="Manufacture of rubber and plastic products"
      9="Manufacture of other non-metallic mineral products"
      10="Manufacture of basic metals"
      11="Manufacture of fabricated metal products, except machinery and equipment"
      12="Manufacture of machinery and equipment n.e.c."
      13="Manufacture of electrical and optical equipment"
      14="Manufacture of transport equipment"
      15="Manufacture of furniture, manufacturing n.e.c., Recycling"
      16="Electricity, gas, steam and hot water supply"
      17="Construction"
      18="Sale, maintenance and repair of motor vehicles and motorcycles, retail sale of automotive fuel"
      19="Wholesale trade and commission trade, except of motor vehicles and motorcycles"
      20="Retail trade, except of motor vehicles and motorcycles, repair of personal and household goods"
      21="Hotels and restaurants"
      22="Land transport, transport via pipelines, water transport, air transport"
      23="Supporting and auxiliary transport activities, activities of travel agencies"
      24="Post and telecommunications"
      25="Financial intermediation"
      26="Real estate activities"
      27="Renting of machinery and equipment without operator and of personal and household goods"
      28="Computer and related activities"
      29="Research and development; other business activities";

VALUE LABELS_4_GROUP
      1="Mainly by the enterprise or enterprise group"
      2="In cooperation with other enterprises or institutions"
      3="Mainly other enterprises or institutions";

VALUE LABELS_5_GROUP
      1="Continuously"
      2="Occasionally";

VALUE LABELS_6_GROUP
      0="Not used"
      1="Low"
      2="Med"
      3="High";

VALUE LABELS_7_GROUP
      1="Other enterprises within enterprise group"
      2="Suppliers of equipment, etc"
      3="Clients or customers"
      4="Competitors or other firms"
      5="Consultants, commercial labs, private R&D institutes"
      6="Universities or other ..."
      7="Government or public research institutes";

VALUE LABELS_8_GROUP
      0="Not relevant"
      1="Low"
      2="Med"
      3="High";

VALUE LABELS_9_GROUP
      0="<50"
      1="50-249"
      2=">=250";

RUN;

* ------------------------------------------------------------------------------ ;


* --- Format variables with value labels ---                                     ;

DATA sasimport;

    SET sasimport;

    FORMAT
    CO62     LABELS_1_GROUP.
    GP       LABELS_1_GROUP.
    MARLOC   LABELS_1_GROUP.
    MARNAT   LABELS_1_GROUP.
    MAREUR   LABELS_1_GROUP.
    MAROTH   LABELS_1_GROUP.
    INPDGD   LABELS_1_GROUP.
    INPDSV   LABELS_1_GROUP.
    NEWMKT   LABELS_1_GROUP.
    NEWFRM   LABELS_1_GROUP.
    INPSPD   LABELS_1_GROUP.
    INPSLG   LABELS_1_GROUP.
    INPSSU   LABELS_1_GROUP.
    INONAB   LABELS_1_GROUP.
    RRDIN    LABELS_1_GROUP.
    RRDEX    LABELS_1_GROUP.
    RMAC     LABELS_1_GROUP.
    ROEK     LABELS_1_GROUP.
    RTR      LABELS_1_GROUP.
    RMAR     LABELS_1_GROUP.
    RPRE     LABELS_1_GROUP.
    FUNLOC   LABELS_1_GROUP.
    FUNGMT   LABELS_1_GROUP.
    FUNEU    LABELS_1_GROUP.
    FUNRTD   LABELS_1_GROUP.
    CO       LABELS_1_GROUP.
    CO11     LABELS_1_GROUP.
    CO12     LABELS_1_GROUP.
    CO13     LABELS_1_GROUP.
    CO14     LABELS_1_GROUP.
    CO21     LABELS_1_GROUP.
    CO22     LABELS_1_GROUP.
    CO23     LABELS_1_GROUP.
    CO24     LABELS_1_GROUP.
    CO31     LABELS_1_GROUP.
    CO32     LABELS_1_GROUP.
    CO33     LABELS_1_GROUP.
    CO34     LABELS_1_GROUP.
    CO41     LABELS_1_GROUP.
    CO42     LABELS_1_GROUP.
    CO43     LABELS_1_GROUP.
    CO44     LABELS_1_GROUP.
    CO51     LABELS_1_GROUP.
    CO52     LABELS_1_GROUP.
    CO53     LABELS_1_GROUP.
    CO54     LABELS_1_GROUP.
    CO61     LABELS_1_GROUP.
    CO63     LABELS_1_GROUP.
    CO64     LABELS_1_GROUP.
    CO71     LABELS_1_GROUP.
    CO72     LABELS_1_GROUP.
    CO73     LABELS_1_GROUP.
    CO74     LABELS_1_GROUP.
    HCON     LABELS_1_GROUP.
    HBEG     LABELS_1_GROUP.
    HDLAY    LABELS_1_GROUP.
    PROPAT   LABELS_1_GROUP.
    PRODSG   LABELS_1_GROUP.
    PROTM    LABELS_1_GROUP.
    PROCP    LABELS_1_GROUP.
    ORGSYS   LABELS_1_GROUP.
    ORGSTR   LABELS_1_GROUP.
    ORGREL   LABELS_1_GROUP.
    MKTDES   LABELS_1_GROUP.
    MKTMET   LABELS_1_GROUP.
    C_HO     LABELS_2_GROUP.
    NACE_PRO LABELS_3_GROUP.
    INPDTW   LABELS_4_GROUP.
    INPCSW   LABELS_4_GROUP.
    RDENG    LABELS_5_GROUP.
    SENTG    LABELS_6_GROUP.
    SSUP     LABELS_6_GROUP.
    SCLI     LABELS_6_GROUP.
    SCOM     LABELS_6_GROUP.
    SINS     LABELS_6_GROUP.
    SUNI     LABELS_6_GROUP.
    SGMT     LABELS_6_GROUP.
    SCON     LABELS_6_GROUP.
    SJOU     LABELS_6_GROUP.
    SPRO     LABELS_6_GROUP.
    PMOS     LABELS_7_GROUP.
    ERANGE   LABELS_8_GROUP.
    EMAR     LABELS_8_GROUP.
    EQUA     LABELS_8_GROUP.
    EFLEX    LABELS_8_GROUP.
    ECAP     LABELS_8_GROUP.
    ELBR     LABELS_8_GROUP.
    EMAT     LABELS_8_GROUP.
    EENV     LABELS_8_GROUP.
    ESTD     LABELS_8_GROUP.
    HFENT    LABELS_8_GROUP.
    HFOUT    LABELS_8_GROUP.
    HCOS     LABELS_8_GROUP.
    HPER     LABELS_8_GROUP.
    HTEC     LABELS_8_GROUP.
    HINF     LABELS_8_GROUP.
    HPAR     LABELS_8_GROUP.
    HDOM     LABELS_8_GROUP.
    HDEM     LABELS_8_GROUP.
    HPRIOR   LABELS_8_GROUP.
    HMAR     LABELS_8_GROUP.
    EFORED   LABELS_8_GROUP.
    EFORQU   LABELS_8_GROUP.
    EFORCO   LABELS_8_GROUP.
    EFORSA   LABELS_8_GROUP.
    SIZE04   LABELS_9_GROUP.
    SIZE06   LABELS_9_GROUP.
    ;

RUN;

* ------------------------------------------------------------------------------ ;


* --- Save data to a sas type file ---                                           ;

DATA dirout.&sasfile;

    SET sasimport;

RUN;
